@@ -14,13 +14,13 @@ from pyunpack import Archive
 from tika import parser
 
 from texta_parsers.email_parser import EmailParser
-from texta_parsers.settings import ES_URL, FACE_VECTOR_FIELD_NAME, META_FIELD
+from texta_parsers.settings import FACE_VECTOR_FIELD_NAME, META_FIELD
 from texta_parsers.tools import rar_extractor, tar_extractor, utils
 from texta_parsers.tools.extension import Extension
 from texta_parsers.tools.scanner import DocScanner
 from . import exceptions
 # for digidoc parser
-from .tools.elastic import ESImporter
+from .exceptions import UnsupportedFileError
 
 
 FNULL = open(os.devnull, "w")
@@ -199,12 +199,15 @@ class DocParser:
                 ### TODO: HOLY SHIT ITS A DIRECTORY INSIDE AN ARCHIVE!
                 pass
             else:
-                extracted_extension = Extension.predict(extracted_path)
-                if extracted_extension in Extension.ARCHIVE_EXTENSIONS:
-                    for doc in self._extract_archive(extracted_path, output_dir, extracted_extension):
-                        yield doc
-                else:
-                    yield {"path": extracted_path, "extension": extracted_extension}
+                try:
+                    extracted_extension = Extension.predict(extracted_path)
+                    if extracted_extension in Extension.ARCHIVE_EXTENSIONS:
+                        for doc in self._extract_archive(extracted_path, output_dir, extracted_extension):
+                            yield doc
+                    else:
+                        yield {"path": extracted_path, "extension": extracted_extension}
+                except UnsupportedFileError as e:
+                    yield {"path": extracted_path, "extension": None}
 
 
     def remove_temp_dir(self):
@@ -266,7 +269,8 @@ class DocParser:
 
             header = "infer" if has_header else None
             # read and yield actual data with pandas (more convenient)
-            reader = pd.read_csv(document["path"], dialect=dialect, chunksize=1000, header=header)
+            # skip rows that thrown an error and hide the warning message with 'warn_bad_lines'
+            reader = pd.read_csv(document["path"], dialect=dialect, chunksize=1000, header=header, error_bad_lines=False, warn_bad_lines=False, dtype='string')
 
             for chunk in reader:
                 for _, row in chunk.iterrows():
@@ -275,7 +279,9 @@ class DocParser:
 
         # .xls or .xlsx
         else:
-            reader = pd.read_excel(document["path"], header=0, sheet_name=None)  # dont know whether there is a header but assume that the first row is
+            # Enforce str type with 'dtype' to avoid schema conflicts in Elasticsearch.
+            # TODO Find a better solution to handle types.
+            reader = pd.read_excel(document["path"], header=0, sheet_name=None, dtype='string')  # dont know whether there is a header but assume that the first row is
 
             if isinstance(reader, dict):
                 for _, df in reader.items():
@@ -320,6 +326,13 @@ class DocParser:
         return True
 
 
+    def _overwrite_bytes_content(self, content: dict):
+        for key, value in content.items():
+            if isinstance(value, bytes):
+                content[key] = ""
+        return content
+
+
     def _parse_attachment(self, attachment):
         parsed_attachment = list(self._parse(attachment["content"], attachment["filename"], save_to_file=False))  # this could be a list of multiple files
 
@@ -412,6 +425,8 @@ class DocParser:
 
                         extracted_attachments = []
                         for attachment in attachment_dicts:
+                            attachment.setdefault(META_FIELD, {})  # Ensure that the meta field exists.
+
                             if ("subject" in attachment):  # is actually mail, do not parse it (already parsed!)
                                 attachment[META_FIELD] = meta.copy()
                                 extracted_attachments.append(attachment)
@@ -422,10 +437,13 @@ class DocParser:
                                     except:
                                         exc_type, value, _ = sys.exc_info()
                                         error_msg = "{}: {}".format(exc_type.__name__, value)
-                                        attachment[META_FIELD]["errors"] = "{}: {}".format(exc_type.__name__, value)
+                                        attachment[META_FIELD]["errors"] = error_msg
                                         extracted_attachments += [attachment]
+                                        # Remove bytes that can be left in because of exceptions as they can
+                                        # not be parsed by Elasticsearch.
+                                        self._overwrite_bytes_content(attachment)
 
-                                    # save attachments if specified
+                                # save attachments if specified
                                     for attachment in extracted_attachments:
                                         if ("subject" not in attachment):  # is actually mail, do not save it (already in email_parser if specified so!)
                                             self.save_attachment(attachment)
@@ -435,7 +453,7 @@ class DocParser:
                                         attachment[META_FIELD] = meta.copy()
                                         if ("subject" not in attachment):
                                             if ("content" in attachment):
-                                                attachment.pop("content")
+                                                attachment.pop("content", None)
                                             self.save_attachment(attachment)
 
                         yield msg_dict, extracted_attachments if self.parse_attachments else attachment_dicts
@@ -472,11 +490,11 @@ class DocParser:
 
     def _remove_temp_path_ref(self, item):
         if (type(item) == tuple):
-            item[0][META_FIELD].pop("path")
+            item[0][META_FIELD].pop("path", None)
             for t in item[1]:
-                t[META_FIELD].pop("path")
+                t[META_FIELD].pop("path", None)
         else:
-            item[META_FIELD].pop("path")
+            item[META_FIELD].pop("path", None)
 
 
     def parse(self, parser_input, file_name=None):
