@@ -1,10 +1,8 @@
 import logging
 import mailbox
-import multiprocessing
 import os
 import shutil
 from random import getrandbits
-from typing import Optional
 
 import magic
 
@@ -13,9 +11,11 @@ from texta_parsers.tools.pst_extractor import check_readpst_exists, extract_pst_
 
 
 SUPPORTED_MAIL_FORMATS = [".mbox", ".pst", ".eml"]
-logging.basicConfig(format='%(levelname)s %(asctime)s: %(message)s',
-                    datefmt='%d.%m.%Y %H:%M:%S',
-                    level=logging.INFO)
+logging.basicConfig(
+    format='%(levelname)s %(asctime)s: %(message)s',
+    datefmt='%d.%m.%Y %H:%M:%S',
+    level=logging.INFO
+)
 
 
 class EmailParser():
@@ -27,10 +27,12 @@ class EmailParser():
     save_path (string): folder for non-temporal files, (optional, default: "parsed_files")
     """
 
+
     def __init__(self, num_threads=1, tmp_folder="tmp", save_path="parsed_files"):
         self.num_threads = num_threads
         self.tmp_folder = tmp_folder
         self.save_path = save_path
+        self.save_mails = None
         if not check_readpst_exists():
             raise FileNotFoundError("Readpst not found. Can not initialize parser.")
 
@@ -55,11 +57,10 @@ class EmailParser():
             if ext == ".mbox":
                 folder_name = email_file.split("/")[-1].split(".")[0]
 
-                with multiprocessing.Pool(processes=self.num_threads) as pool:
-                    for msg_json, attachment_jsons in pool.imap(self._parse_msg, mailbox.mbox(email_file)):
-                        if (msg_json != {}):
-                            msg_json["original_folder"] = folder_name
-                        yield msg_json, attachment_jsons
+                for msg_json, attachment_jsons in map(self._parse_msg, mailbox.mbox(email_file)):
+                    if (msg_json != {}):
+                        msg_json["original_folder"] = folder_name
+                    yield msg_json, attachment_jsons
 
             elif ext == ".pst":
                 extracted_mboxes = extract_pst_file(email_file, self.tmp_folder)
@@ -67,11 +68,10 @@ class EmailParser():
                     logging.info("Parsing from .pst {}".format(mbox_file))
                     folder_name = mbox_file.split("/")[-1].split(".")[0]
 
-                    with multiprocessing.Pool(processes=self.num_threads) as pool:
-                        for msg_json, attachment_jsons in pool.imap(self._parse_msg, mailbox.mbox(mbox_file)):
-                            if (msg_json != {}):
-                                msg_json["original_folder"] = folder_name
-                            yield msg_json, attachment_jsons
+                    for msg_json, attachment_jsons in map(self._parse_msg, mailbox.mbox(mbox_file)):
+                        if (msg_json != {}):
+                            msg_json["original_folder"] = folder_name
+                        yield msg_json, attachment_jsons
 
                 self._delete_extracted_pst(self.tmp_folder)
 
@@ -82,7 +82,7 @@ class EmailParser():
                 yield msg_json, attachment_jsons
 
 
-    def _parse_msg_rec(self, msg, msg_id):
+    def _parse_msg_rec(self, msg, msg_id: str):
         """Parses given message recursively using parsers in message module for different parts
         """
         is_root_msg = msg_id == ""
@@ -103,7 +103,7 @@ class EmailParser():
             msg_data["filename"] = filename
 
             for attachment in attachments:
-                #replace parent_id the id of correct parent
+                # replace parent_id the id of correct parent
                 attachment["parent_id"] = msg_data["id"]
             attachments.append(msg_data)
 
@@ -114,7 +114,7 @@ class EmailParser():
                     _, nested_attachments = self._parse_msg_rec(payload, msg_id)
 
                     if (self.save_mails):
-                        #save sub-mails if required as we won't see it's payload later
+                        # save sub-mails if required as we won't see it's payload later
                         print("saving mail with id", nested_attachments[-1]["id"])
                         filepath = self._save_mail_as_eml(payload, msg_id + "/" + nested_attachments[-1]["id"])
                         if (filepath):
@@ -135,7 +135,7 @@ class EmailParser():
             return msg_json, attachment_jsons
         except Exception as e:
             # in case all other more specific exceptions handlers have failed
-            logging.exception(e)
+            logging.warning(e)
             return {}, []
 
 
@@ -238,7 +238,7 @@ class EmailParser():
 
     def _save_mail_as_eml(self, message, msg_id):
         save_path = os.path.join(self.save_path, "mails")
-        msg_path = os.path.join(save_path,  msg_id + ".eml")
+        msg_path = os.path.join(save_path, msg_id + ".eml")
 
         if not os.path.exists(os.path.dirname(msg_path)):
             os.makedirs(os.path.dirname(msg_path))
