@@ -5,11 +5,11 @@ import warnings
 import elasticsearch
 import elasticsearch_dsl
 from elasticsearch.helpers import bulk
-from elasticsearch_dsl import Keyword, Long, Mapping, Nested, DenseVector
+from elasticsearch_dsl import DenseVector, Keyword, Long, Mapping, Nested
 
 from . import utils
 from .utils import ParserOutputType
-from ..settings import ES_URL, META_FIELD, FACE_VECTOR_FIELD_NAME
+from ..settings import ELASTIC_BULK_BATCH_SIZE, ELASTIC_GLOBAL_TIMEOUT, ES_URL, FACE_VECTOR_FIELD_NAME, META_FIELD
 
 
 logging.basicConfig(
@@ -28,12 +28,12 @@ class ESImporter:
         :param index_prefix: Prefix used for naming indices in elasticsearch
         """
         self.index_prefix = index_prefix
-        self.es = elasticsearch.Elasticsearch(elastic_url)
+        self.es = elasticsearch.Elasticsearch(elastic_url, timeout=ELASTIC_GLOBAL_TIMEOUT)
 
 
     @staticmethod
     def build_flavor(elastic_url: str) -> str:
-        es = elasticsearch.Elasticsearch(elastic_url)
+        es = elasticsearch.Elasticsearch(elastic_url, timeout=ELASTIC_GLOBAL_TIMEOUT)
         return es.info()["version"]["build_flavor"]
 
 
@@ -83,7 +83,7 @@ class ESImporter:
         self._add_texta_face_vectors_mapping(index_name)
         generator = self._importer_generator(generator, index_name)
         generator = list(generator)
-        bulk(client=self.es, actions=generator, refresh="wait_for")
+        bulk(client=self.es, actions=generator, chunk_size=ELASTIC_BULK_BATCH_SIZE, refresh="wait_for")
         logging.info("Finished pushing person info into Elasticsearch!")
         return True
 
@@ -100,7 +100,8 @@ class ESImporter:
         if (toolkit_url != None and tk_media_folder == None):
             raise ValueError("Argument tk_media_folder can not be None if toolkit_url is given.")
 
-        bulk(actions=self._get_es_data(generator, toolkit_url, tk_media_folder), client=self.es, refresh="wait_for")
+        actions = self._get_es_data(generator, toolkit_url, tk_media_folder)
+        bulk(actions=actions, client=self.es, chunk_size=ELASTIC_BULK_BATCH_SIZE, refresh="wait_for")
 
 
     def _get_es_data(self, generator, toolkit_url, tk_media_folder):
@@ -177,7 +178,7 @@ class ESImporter:
 
     def get_doc_type_for_index(self, index: str):
         index_interface = elasticsearch_dsl.Index(index, using=self.es)
-        mapping = index_interface.get_mapping()
+        mapping = index_interface.get_mapping(include_type_name=True)
         doc_type = self.parse_doc_type_from_mapping(mapping)
         return doc_type
 
