@@ -1,5 +1,9 @@
 import logging
 
+from texta_parsers.settings import META_FIELD
+from texta_parsers.tools.extension import Extension
+
+
 logging.basicConfig(
     format='%(levelname)s %(asctime)s: %(message)s',
     datefmt='%d.%m.%Y %H:%M:%S',
@@ -11,6 +15,8 @@ class MLPProcessor:
     """
     A wrapper class to apply MLP to DocParser documents.
     """
+
+
     def __init__(self, mlp):
         self.mlp = mlp
         self.IGNORE_FIELDS = ("texta_facts", "properties", "texta_face_vectors")
@@ -38,7 +44,7 @@ class MLPProcessor:
             mlp_res = self.mlp.process(content, analyzers=analyzers)
             mlp_res_path = field + "_mlp"
             # Add the MLP output dictionary.
-            document[mlp_res_path] = mlp_res["text"] 
+            document[mlp_res_path] = mlp_res["text"]
 
             facts = []
             for f in mlp_res["texta_facts"]:
@@ -56,9 +62,17 @@ class MLPProcessor:
 
 
     def _apply_mlp_to_item(self, item: dict, analyzers: list):
-        # apply it to all fields as we don't know anything about the item or it's fields
-        item_copy = item.copy()
-        for key in item_copy.keys():
-            if key not in self.IGNORE_FIELDS:
-                self._apply_mlp(item, key, analyzers)
-
+        """
+        Apply MLP on all items exceptions those that come from a collection file
+        as they might have a huge amount of fields that don't necessarily need parsing.
+        """
+        has_proper_fields = META_FIELD in item and 'extension' in item[META_FIELD]
+        if has_proper_fields:
+            extension = item[META_FIELD]['extension']
+            if extension in Extension.COLLECTION_EXTENSIONS:
+                pass
+            else:
+                item_copy = item.copy()
+                for key in item_copy.keys():
+                    if key not in self.IGNORE_FIELDS:
+                        self._apply_mlp(item, key, analyzers)
